import service from './service.js';

let main = document.querySelector('main');
main.innerHTML = 'Loading quotes, please wait...';

let promises = [];
for (let i = 0; i < 3; i++) {
	promises[i] = service.getTranslatedQuote();
}
Promise.all(promises)
	.then(quotes => displayQuotes(quotes))
	.catch(error => displayError(error));

/* Implementation with async and await
let quotes = [];
let count = 0;
while (count < 3) {
	try {
		quotes[count] = await service.getTranslatedQuote();
		count++;
	} catch (error) { displayError(error); }
}
displayQuotes(quotes);
*/

function displayQuotes(quotes) {
	main.innerHTML = '';
	quotes.forEach(quote => main.innerHTML += `<p>${quote.text}<br>&mdash; ${quote.author || 'Unbekannter Autor'}</p>`);
}

function displayError(error) {
	main.innerHTML = error.status ? `<p>Error: ${error.statusText} (${error.status})</p>` : 'Unexpected network error';
}
